@@ -87,7 +87,7 @@ private Q_SLOTS:
     {
         AkonadiTest::checkTestIsIsolated();
         AkonadiTest::setAllResourcesOffline();
-        Akonadi::AgentInstance agent = Akonadi::AgentManager::self()->instance(QStringLiteral("akonadi_knut_resource_0"));
+        Akonadi::AgentInstance agent = Akonadi::AgentManager::self()->instance(u"akonadi_knut_resource_0"_s);
         QVERIFY(agent.isValid());
         agent.setIsOnline(true);
 
