@@ -5,6 +5,8 @@
 */
 
 #include "akonadisearchdebugwidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../akonadisearchdebugsearchpathcombobox.h"
 #include "../akonadisearchdebugwidget.h"
 #include <KLineEdit>
@@ -22,26 +24,26 @@ AkonadiSearchDebugWidgetTest::~AkonadiSearchDebugWidgetTest() = default;
 void AkonadiSearchDebugWidgetTest::shouldHaveDefaultValue()
 {
     Akonadi::Search::AkonadiSearchDebugWidget widget;
-    auto button = widget.findChild<QPushButton *>(QStringLiteral("searchbutton"));
+    auto button = widget.findChild<QPushButton *>(u"searchbutton"_s);
     QVERIFY(button);
     QVERIFY(!button->isEnabled());
-    auto lineEdit = widget.findChild<KLineEdit *>(QStringLiteral("lineedit"));
+    auto lineEdit = widget.findChild<KLineEdit *>(u"lineedit"_s);
     QVERIFY(lineEdit);
     QVERIFY(lineEdit->text().isEmpty());
     QVERIFY(lineEdit->trapReturnKey());
     QVERIFY(lineEdit->isClearButtonEnabled());
-    auto editorWidget = widget.findChild<QPlainTextEdit *>(QStringLiteral("plaintexteditor"));
+    auto editorWidget = widget.findChild<QPlainTextEdit *>(u"plaintexteditor"_s);
     QVERIFY(editorWidget->isReadOnly());
     QVERIFY(editorWidget);
     QVERIFY(editorWidget->toPlainText().isEmpty());
-    auto searchCombo = widget.findChild<Akonadi::Search::AkonadiSearchDebugSearchPathComboBox *>(QStringLiteral("searchpathcombo"));
+    auto searchCombo = widget.findChild<Akonadi::Search::AkonadiSearchDebugSearchPathComboBox *>(u"searchpathcombo"_s);
     QVERIFY(searchCombo);
 }
 
 void AkonadiSearchDebugWidgetTest::shouldFillLineEditWhenWeWantToSearchItem()
 {
     Akonadi::Search::AkonadiSearchDebugWidget widget;
-    auto lineEdit = widget.findChild<KLineEdit *>(QStringLiteral("lineedit"));
+    auto lineEdit = widget.findChild<KLineEdit *>(u"lineedit"_s);
     const int value = 42;
     const QString akonadiItem = QString::number(value);
     widget.setAkonadiId(value);
@@ -53,15 +55,15 @@ void AkonadiSearchDebugWidgetTest::shouldEnabledPushButtonWhenLineEditIsNotEmpty
     Akonadi::Search::AkonadiSearchDebugWidget widget;
     const int value = 42;
     widget.setAkonadiId(value);
-    auto button = widget.findChild<QPushButton *>(QStringLiteral("searchbutton"));
+    auto button = widget.findChild<QPushButton *>(u"searchbutton"_s);
     QVERIFY(button->isEnabled());
 
-    auto lineEdit = widget.findChild<KLineEdit *>(QStringLiteral("lineedit"));
+    auto lineEdit = widget.findChild<KLineEdit *>(u"lineedit"_s);
     lineEdit->setText(QString());
     QVERIFY(!button->isEnabled());
 
     // trimmed string
-    lineEdit->setText(QStringLiteral(" "));
+    lineEdit->setText(u" "_s);
     QVERIFY(!button->isEnabled());
 }
 
@@ -70,7 +72,7 @@ void AkonadiSearchDebugWidgetTest::shouldChangeSearchType()
     Akonadi::Search::AkonadiSearchDebugWidget widget;
     Akonadi::Search::AkonadiSearchDebugSearchPathComboBox::SearchType type = Akonadi::Search::AkonadiSearchDebugSearchPathComboBox::Emails;
     widget.setSearchType(type);
-    auto searchCombo = widget.findChild<Akonadi::Search::AkonadiSearchDebugSearchPathComboBox *>(QStringLiteral("searchpathcombo"));
+    auto searchCombo = widget.findChild<Akonadi::Search::AkonadiSearchDebugSearchPathComboBox *>(u"searchpathcombo"_s);
     const QString path = searchCombo->pathFromEnum(type);
     QCOMPARE(searchCombo->searchPath(), path);
 }
